@@ -1,5 +1,5 @@
 ##########################################################################
-# Copyright (c) 2010-2012,2018 Alexander Bluhm <alexander.bluhm@gmx.net>
+# Copyright (c) 2010-2019 Alexander Bluhm <alexander.bluhm@gmx.net>
 #
 # Permission to use, copy, modify, and distribute this software for any
 # purpose with or without fee is hereby granted, provided that the above
@@ -48,7 +48,7 @@ C<show database link>
 C<show database intra>
 is needed.
 It can be given as separate files or obtained dynamically.
-In the latter case B<sudo> is invoked if permissions are not
+In the latter case B<doas> is invoked if permissions are not
 sufficient to run B<ospf6ctl>.
 If the object has been created with the C<ssh> argument, the specified
 user and host are used to login and run B<ospf6ctl> there.
@@ -68,8 +68,10 @@ use fields qw(
 
 sub new {
     my OSPF::LSDB::ospf6d $self = OSPF::LSDB::ospfd::new(@_);
+    $self->{ospfd} = "ospf6d";
     $self->{ospfctl} = "ospf6ctl";
-    $self->{ospfsock} = "/var/run/ospf6d.sock";
+    # XXX hard coded routing domain 0
+    $self->{ospfsock} = "/var/run/ospf6d.sock.0";
     %{$self->{showdb}} = (%{$self->{showdb}}, (
 	link   => "link",
 	intra  => "intra",
@@ -151,10 +153,10 @@ sub parse_router {
 	    if (/\(Interface ID $IP\)/) {
 		$l->{interface} = $1;
 	    }
-	} elsif (/^    Designated Router ID: $IP$/) {
+	} elsif (/^    (?:Designated )?Router ID: $IP$/) {
 	    $l->{routerid} = $1;
 	    $link = $1;
-	} elsif (/^    DR Interface ID: $IP$/) {
+	} elsif (/^    (?:DR )?Interface ID: $IP$/) {
 	    $l->{address} = $1;
 	    $link = "$1\@$link";
 	} elsif (/^    Metric: $RE{num}{int}{-keep}$/) {
